@@ -16,7 +16,7 @@ comm.close()
 
 from queue import Queue
 import time,threading
-#import serial
+import serial
 import random
 serialPort = "COM10"  # 串口
 baudRate = 9600  # 波特率
@@ -24,10 +24,16 @@ baudRate = 9600  # 波特率
 recQueue = Queue(maxsize=0)
 sendQueue = Queue(maxsize=0)
 
-stopSign = [False]
 paras=[False,'COM1',9600,False]
 
 def start(com='COM1',baudRate= 9600,verbose = False):
+    '''
+    Start the communication thread.
+    Paras:
+        com: serial port name
+        baudRate: baud Reate in bits per second.
+        berbose: if show the deatil message, default value is False.
+    '''
     paras[0] = False
     paras[1] = com
     paras[2] = baudRate
@@ -35,6 +41,10 @@ def start(com='COM1',baudRate= 9600,verbose = False):
     commThread.start()
     
 def stop():
+    '''
+    Stop the communicatoon thread.
+    paras: None
+    '''
     paras[0] = False
     
     
@@ -89,18 +99,19 @@ def comm():
 commThread=threading.Thread(target=comm)
 
 # folowing code is used for test and will be deleted after test        
+stopSign = [False]
 def control():
     ticks = 0
     while not stopSign[0]:
         ticks =  ticks + 1
         if ticks >= 10:
-            stop()
+            stopSign[0] = True
         else:
             time.sleep(1)
     print('bye')
         
         
-def product():
+def produce():
     while not stopSign[0]:
         t = []
         t.append(b'\x11\x12')
@@ -120,9 +131,9 @@ def consume():
     print('consumer stop')
 if __name__ == '__main__':
     controler =threading.Thread(target=control)
-    t1=threading.Thread(target=product)
+    t1=threading.Thread(target=produce)
     t2=threading.Thread(target=consume)
-    
+
     controler.start()
     t1.start()
     t2.start()
